-module(dummy_proj_server).

-behaviour(gen_server).

%% API
-export([start_link/0, poke/0, num_pokes/0]).

%% gen_server callbacks
-export([init/1, handle_call/3, handle_cast/2,
         handle_info/2, terminate/2, code_change/3]).

-record(state, {count}).

-define(SERVER, ?MODULE).


%% API Interfaces

start_link() ->
  gen_server:start_link({local, ?SERVER}, ?MODULE, [], []).

poke() ->
  gen_server:call(?SERVER, poke).

num_pokes() ->
  gen_server:call(?SERVER, num_pokes).


%% gen_server callbacks implementation
init([]) ->
  {ok, #state{count = 0}}.

handle_call(poke, _From, #state{count = Count} = State) ->
  Reply = {ok, Count+1},
  {reply, Reply, State#state{count = Count+1}};

handle_call(num_pokes, _From, #state{count = Count} = State) ->
  {reply, Count, State}.

handle_cast(_Request, State) ->
  {noreply, State}.

handle_info(_Request, State) ->
  {noreply, State}.

terminate(_Reason, _State) ->
  ok.

code_change(_OldVsn, State, _Extra) ->
  {ok, State}.

